package status

//20x 一定是正确。所有异常都不使用200返回码
//10x 用于指定客户端应相应的某些动作。
//20x 用于表示请求成功。
//30x 表示要完成请求，需要进一步操作（重定向）。
//40x 客户端请求问题
//50x 服务器错误。

//错误码的前3位是http status code
const (
	//10x 消息

	//20x 成功----------------------------------------------------------------------------------/
	OK = 200 //成功

	// 400xx StatusBadRequest：请求参数有误，当前请求无法被服务器理解
	BadRequest      = 400001 // 通用型，错误的请求
	PwdIllegal      = 400002 // 密码不合法
	CaptchaErr      = 400003 // 验证码错误
	CheckSignFail   = 400004 // 验证签名失败
	TelOrCaptchaErr = 400005 // 手机号或验证码错误

	//402xx StatusUnauthorized  当前请求需要用户验证
	Unauthorized        = 402001 //用户没有登录
	AccessTokenExpired  = 402002 //access token过期
	RefreshTokenExpired = 402003 //refresh token过期
	RefreshTokenInvalid = 402004 //refresh token无效

	//403xx StatusForbidden 服务器已经理解请求，但是拒绝执行它
	Forbidden                  = 403001 // 通用型, 服务器拒绝执行
	LoginFail                  = 403002 // 登录失败，账号或密码错误
	UserNameUsed               = 403003 // 用户名已使用
	EmailUsed                  = 403004 // 邮箱已使用
	TelUsed                    = 403005 // 手机号已使用
	LogoutFail                 = 403006 // 登出失败
	RegisterFail               = 403007 // 注册失败
	UpdateTokenFail            = 403008 // 更新token失败
	UpdateFail                 = 403009 // 更新失败
	LockUserAuthed             = 403012 // 用户已授权
	ServerBusy                 = 403022 // 服务器繁忙，请稍后再试
	MoneySufficient            = 403024 // 余额不足
	UserHasBeenInvited         = 403029 // 用户已被邀请过
	UserSelfInviteSelf         = 403030 // 不允自己邀请自己
	OutOffWithdrawCountLimit   = 403041 // 超出当月提现次数
	OutOffWithdrawAccountLimit = 403042 // 超出提现金额范围
	CaptchaDelivered           = 403044 // 验证码已发出
	NeedBindTel                = 403045 // 需要绑定手机号
	ShoppingTimesNotEnough     = 403046 // 购物次数不足
	UserVmNotEnough            = 403049 // 用户积分余额不足

	HbKeySendFail = 403055 // 口令发送失败，60秒后重试
	IsNoviceFail  = 403056 // 不是新用户

	CheckInAlready   = 403060 // 今日已经签到
	OpenChestTimeNot = 403061 // 宝箱时间未到

	ExchangeStepLimit = 403070 // 今日兑换步数超出上限

	HaveUnreturnedOrders = 403080 // 请归还未完成订单
	GoodsSoldOut         = 403090 // 商品已下架
	//404xx StatusNotFound  请求失败，请求所希望得到的资源未被在服务器上发现
	NotExists = 404001 // 通用型，请求的资源不存在

	UserNotExists = 404002 // 用户不存在
	LockNotExists = 404003 // 锁不存在
	IsExists      = 405001

	//500xx StatusInternalServerError  服务器遇到了一个未曾预料的状况，导致了它无法完成对请求的处理。
	InternalServerError  = 500001 // 通用型，服务器内部错误
	SmsFail              = 500002 // 短信发送失败
	JsonParseError       = 500005 // json解析错误
	JsonCreateError      = 500006 // json生成错误
	DBOperateError       = 500007 // 数据库操作错误
	RpcError             = 500008 // RPC调用错误
	RequestTimeout       = 500009 // 请求超时
	InviteUserFail       = 500015 // 邀请码邀请失败
	RewardUsedByTaskFail = 500016 // 奖励关联其它任务，无法删除

	PayStateIng  = 500300 // 等待支付结果
	PayStateFail = 500301 // 等待支付结果

	AwardOffShelves  = 500407 //奖品下架
	AwardExchangeOut = 500408 //奖品已兑完

	NotMember                          = 500501 //非会员
	HadReceiveReward                   = 500502 // 已经领取过奖励
	OrderDelivered                     = 500503 // 订单已发货
	OrderCompleted                     = 500504 // 订单已完成
	OrderStockOut                      = 500505 // 没有库存
	OrderUnpaidDeposit                 = 500506 // 未交押金
	RefundDepositSubmitted             = 500507 // 已提交押金退款
	OrderMemberLevelLow                = 500508 // 会员等级低
	OrderOutRentCount                  = 500509 // 会员超过可借卡数
	OrderStatusNotReturning            = 500510 // 订单已完成
	ShareCardBillStateCancelError      = 500511 // 共享单状态不能取消
	ShareCardRetrieveExistAppliedCard  = 500513 // 存在重复申请收回的卡
	IssueFeedbackReceiptTimeOver48Hour = 500514 // 问题反馈 超过 48小时
	CardRetrieveBefore6Month           = 500515 // 用户收回卡需要半年后
	IssueFeedbackRepetition            = 500516 // 问题反馈已存在,不能重复反馈
	TodayAttendance                    = 500517 // 已签到
	NoAuth                             = 500519 // 没有权限
	GoodsNotSale                       = 500508 // 商品已下架
	StateNotCancel                     = 500521 // 状态不能取消
	UserFocusHasCoupon                 = 500522 // 用户已经领取了兑换券

	ToastErr = 600 // 报错
)

var statusDesc = map[int]string{
	OK: "成功",

	BadRequest:             "参数不合法，请检查参数",
	PwdIllegal:             "密码不合法",
	CaptchaErr:             "验证码错误",
	CheckSignFail:          "验证签名失败",
	TelOrCaptchaErr:        "手机号或验证码错误",
	NeedBindTel:            "需要绑定手机号",
	ShoppingTimesNotEnough: "购物次数不足",

	Unauthorized:        "用户没有登录",
	AccessTokenExpired:  "access token过期",
	RefreshTokenExpired: "refresh token过期",
	RefreshTokenInvalid: "refresh token invalid",
	LoginFail:           "登录失败，账号或密码错误",
	UserNameUsed:        "用户名已使用",
	EmailUsed:           "邮箱已使用",
	TelUsed:             "手机号已使用",
	LogoutFail:          "登出失败",
	RegisterFail:        "注册失败",
	UpdateTokenFail:     "更新token失败",
	UpdateFail:          "更新失败",
	LockUserAuthed:      "用户已授权",
	ServerBusy:          "服务器繁忙,请稍后再试",

	HaveUnreturnedOrders: "请归还未完成订单",
	GoodsSoldOut:         "商品已下架",
	UserNotExists:        "用户不存在",

	CheckInAlready:   "今日已签到",
	OpenChestTimeNot: "宝箱时间未到",

	ExchangeStepLimit: "今日兑换步数超出上限",

	NotExists:               "请求的资源不存在",
	IsExists:                "资源已经存在",
	OrderStatusNotReturning: "该卡状态不能取消",

	InternalServerError: "服务器开小差了，请稍后再试",
	SmsFail:             "短信发送失败",
	JsonParseError:      "服务器开小差了，请稍后再试",
	JsonCreateError:     "服务器开小差了，请稍后再试",
	DBOperateError:      "服务器开小差了，请稍后再试",
	RpcError:            "服务器开小差了，请稍后再试",
	RequestTimeout:      "服务器开小差了，请稍后再试",

	InviteUserFail: "邀请失败",

	UserHasBeenInvited:         "用户已被邀请过",
	UserSelfInviteSelf:         "不允许自己邀请自己",
	OutOffWithdrawCountLimit:   "超出当月提现次数",
	OutOffWithdrawAccountLimit: "超出提现金额范围",
	CaptchaDelivered:           "验证码5分钟内有效",

	PayStateIng:     "支付中",
	PayStateFail:    "支付失败",
	MoneySufficient: "余额不足",

	AwardOffShelves:  "奖品已下架",
	AwardExchangeOut: "奖品已兑完",

	GoodsNotSale:       "商品已下架",
	StateNotCancel:     "状态不能取消",
	UserFocusHasCoupon: "你已经兑换了优惠券",

	NotMember:        "非会员",
	HadReceiveReward: "已经领取过了",
}

var statusMsg = map[int]string{
	OK: "成功",

	BadRequest:      "参数不合法，请检查参数",
	PwdIllegal:      "密码不合法",
	CaptchaErr:      "验证码错误",
	CheckSignFail:   "验证签名失败",
	TelOrCaptchaErr: "手机号或验证码错误",

	Unauthorized:       "用户没有登录",
	AccessTokenExpired: "token过期",
	LoginFail:          "登录失败，账号或密码错误",
	UserNameUsed:       "用户名已使用",
	EmailUsed:          "邮箱已使用",
	TelUsed:            "手机号已使用",
	LogoutFail:         "登出失败",
	RegisterFail:       "注册失败",
	UpdateTokenFail:    "更新token失败",
	UpdateFail:         "更新失败",
	LockUserAuthed:     "用户已授权",
	ServerBusy:         "服务器繁忙,请稍后再试",

	HaveUnreturnedOrders: "请归还未完成订单",
	GoodsSoldOut:         "商品已下架",

	UserNotExists: "用户不存在",

	HbKeySendFail: "口令发送失败，60秒后重试",
	IsNoviceFail:  "该用户不是新用户",

	CheckInAlready: "今日已签到",
	NoAuth:         "没有权限",

	OpenChestTimeNot: "宝箱时间未到",

	NotExists:         "请求的资源不存在",
	IsExists:          "资源已经存在",
	OrderOutRentCount: "借卡数量超了",

	InternalServerError: "服务器开小差了，请稍后再试",
	SmsFail:             "短信发送失败",
	JsonParseError:      "服务器开小差了，请稍后再试",
	JsonCreateError:     "服务器开小差了，请稍后再试",
	DBOperateError:      "服务器开小差了，请稍后再试",
	RpcError:            "服务器开小差了，请稍后再试",
	RequestTimeout:      "服务器开小差了，请稍后再试",
	InviteUserFail:      "邀请失败",

	UserHasBeenInvited:                 "用户已被邀请过",
	UserSelfInviteSelf:                 "不允许自己邀请自己",
	OutOffWithdrawCountLimit:           "超出每天提现次数",
	OutOffWithdrawAccountLimit:         "超出提现金额范围",
	CaptchaDelivered:                   "验证码5分钟内有效",
	ShareCardBillStateCancelError:      "当前状态不能取消",
	ShareCardRetrieveExistAppliedCard:  "存在重复申请收回的卡",
	IssueFeedbackReceiptTimeOver48Hour: "签收后已超过48小时",
	CardRetrieveBefore6Month:           "收回的卡需共享满半年",
	IssueFeedbackRepetition:            "改卡反馈已存在,不能重复反馈",
	TodayAttendance:                    "今天已签到",
	PayStateIng:                        "支付中",
	PayStateFail:                       "支付失败",
	MoneySufficient:                    "余额不足",
	UserVmNotEnough:                    "积分余额不足",

	UserFocusHasCoupon: "你已经兑换了优惠券",

	AwardOffShelves:  "奖品已下架",
	AwardExchangeOut: "奖品已兑完",

	GoodsNotSale: "商品已下架",

	NotMember:        "非会员",
	HadReceiveReward: "已经领取过了",
}

func StatusDesc(code int) string {
	return statusDesc[code]
}

func StatusMsg(code int) string {
	return statusMsg[code]
}

func HttpStatusCode(code int) int {
	for code > 999 {
		code = code / 10
	}
	return code
}
